@@ -54,6 +54,7 @@ int IGMPATTR;
 int IGRPATTR;
 int GREATTR;
 int ARPATTR;
+int UNKNIPATTR;
 int UNKNATTR;
 
 
@@ -61,22 +62,22 @@ int UNKNATTR;
 
 void draw_desktop(void)
 {
-    int row;			/* counter for desktop construction */
+    int row;                    /* counter for desktop construction */
     char sp_buf[10];
-    
+
     sprintf(sp_buf, "%%%dc", COLS);
     scrollok(stdscr, 0);
     attrset(STATUSBARATTR);
     move(0, 0);
-    printw(sp_buf, ' ');	/* these two print the top n' bottom */
+    printw(sp_buf, ' ');        /* these two print the top n' bottom */
     move(LINES - 1, 0);
-    printw(sp_buf, ' ');	/* lines */
+    printw(sp_buf, ' ');        /* lines */
 
     attrset(FIELDATTR);
 
-    for (row = 1; row <= LINES - 2; row++) {	/* draw the background */
-	move(row, 0);
-	printw(sp_buf, ' ');
+    for (row = 1; row <= LINES - 2; row++) {    /* draw the background */
+        move(row, 0);
+        printw(sp_buf, ' ');
     }
 
     refresh();
@@ -95,16 +96,17 @@ void about()
     wtimeout(win, -1);
     wattrset(win, BOXATTR);
     tx_colorwin(win);
-    box(win, ACS_VLINE, ACS_HLINE);
+    tx_box(win, ACS_VLINE, ACS_HLINE);
     wattrset(win, STDATTR);
     mvwprintw(win, 1, 2, "IPTraf");
     mvwprintw(win, 2, 2, "An IP Network Statistics Utility");
     mvwprintw(win, 3, 2, "Version %s", VERSION);
     mvwprintw(win, 5, 2, "Written by Gerard Paul Java");
-    mvwprintw(win, 6, 2, "Copyright (c) Gerard Paul Java 1997-2002");
+    mvwprintw(win, 6, 2, "Copyright (c) Gerard Paul Java 1997-2004");
     mvwprintw(win, 8, 2, "This program is open-source software released");
     mvwprintw(win, 9, 2, "under the terms of the GNU General Public");
-    mvwprintw(win, 10, 2, "Public License Version 2 or any later version.");
+    mvwprintw(win, 10, 2,
+              "Public License Version 2 or any later version.");
     mvwprintw(win, 11, 2, "See the included LICENSE file for details.");
 
     wattrset(win, HIGHATTR);
@@ -114,9 +116,9 @@ void about()
     doupdate();
 
     do {
-	ch = wgetch(win);
-	if (ch == 12)
-	    tx_refresh_screen();
+        ch = wgetch(win);
+        if (ch == 12)
+            tx_refresh_screen();
     } while (ch == 12);
 
     del_panel(panel);
@@ -125,15 +127,15 @@ void about()
     doupdate();
 }
 
-void show_sort_statwin(WINDOW **statwin, PANEL **panel)
+void show_sort_statwin(WINDOW ** statwin, PANEL ** panel)
 {
     *statwin = newwin(5, 30, (LINES - 5) / 2, (COLS - 30) / 2);
     *panel = new_panel(*statwin);
-    
+
     wattrset(*statwin, BOXATTR);
     tx_colorwin(*statwin);
-    box(*statwin, ACS_VLINE, ACS_HLINE);
-    
+    tx_box(*statwin, ACS_VLINE, ACS_HLINE);
+
     wattrset(*statwin, STDATTR);
     mvwprintw(*statwin, 2, 2, "Sorting, please wait...");
 }
@@ -169,7 +171,8 @@ void stdexitkeyhelp(void)
 
 void scrollkeyhelp(void)
 {
-    tx_printkeyhelp("Up/Down/PgUp/PgDn", "-scroll window  ", stdscr, HIGHATTR, STDATTR);
+    tx_printkeyhelp("Up/Down/PgUp/PgDn", "-scroll window  ", stdscr,
+                    HIGHATTR, STDATTR);
 }
 
 void tabkeyhelp(WINDOW * win)
@@ -189,74 +192,76 @@ void indicate(char *message)
 
 void printlargenum(unsigned long long i, WINDOW * win)
 {
-    if (i < 100000000)		/* less than 100 million */
-	wprintw(win, "%9llu", i);
-    else if (i < 1000000000)	/* less than 1 billion */
-	wprintw(win, "%8lluK", i / 1000);
-    else if (i < 1000000000000ULL)	/* less than 1 trillion */
-	wprintw(win, "%8lluM", i / 1000000);
-    else if (i < 1000000000000000ULL)	/* less than 1000 trillion */
-	wprintw(win, "%8lluG", i / 1000000000ULL);
+    if (i < 100000000)          /* less than 100 million */
+        wprintw(win, "%9llu", i);
+    else if (i < 1000000000)    /* less than 1 billion */
+        wprintw(win, "%8lluK", i / 1000);
+    else if (i < 1000000000000ULL)      /* less than 1 trillion */
+        wprintw(win, "%8lluM", i / 1000000);
+    else if (i < 1000000000000000ULL)   /* less than 1000 trillion */
+        wprintw(win, "%8lluG", i / 1000000000ULL);
     else
-	wprintw(win, "%8lluT", i / 1000000000000ULL);
+        wprintw(win, "%8lluT", i / 1000000000000ULL);
 }
 
 void standardcolors(int color)
 {
     if ((color) && (has_colors())) {
-	init_pair(1, COLOR_BLUE, COLOR_WHITE);
-	init_pair(2, COLOR_BLACK, COLOR_CYAN);
-	init_pair(3, COLOR_CYAN, COLOR_BLUE);
-	init_pair(4, COLOR_YELLOW, COLOR_RED);
-	init_pair(5, COLOR_WHITE, COLOR_RED);
-	init_pair(6, COLOR_BLUE, COLOR_CYAN);
-	init_pair(7, COLOR_BLUE, COLOR_WHITE);
-	init_pair(9, COLOR_RED, COLOR_WHITE);
-	init_pair(10, COLOR_GREEN, COLOR_BLUE);
-	init_pair(11, COLOR_CYAN, COLOR_BLACK);
-	init_pair(12, COLOR_RED, COLOR_CYAN);
-	init_pair(14, COLOR_YELLOW, COLOR_BLUE);
-	init_pair(15, COLOR_YELLOW, COLOR_BLACK);
-	init_pair(16, COLOR_WHITE, COLOR_CYAN);
-	init_pair(17, COLOR_YELLOW, COLOR_CYAN);
+        init_pair(1, COLOR_BLUE, COLOR_WHITE);
+        init_pair(2, COLOR_BLACK, COLOR_CYAN);
+        init_pair(3, COLOR_CYAN, COLOR_BLUE);
+        init_pair(4, COLOR_YELLOW, COLOR_RED);
+        init_pair(5, COLOR_WHITE, COLOR_RED);
+        init_pair(6, COLOR_BLUE, COLOR_CYAN);
+        init_pair(7, COLOR_BLUE, COLOR_WHITE);
+        init_pair(9, COLOR_RED, COLOR_WHITE);
+        init_pair(10, COLOR_GREEN, COLOR_BLUE);
+        init_pair(11, COLOR_CYAN, COLOR_BLACK);
+        init_pair(12, COLOR_RED, COLOR_CYAN);
+        init_pair(14, COLOR_YELLOW, COLOR_BLUE);
+        init_pair(15, COLOR_YELLOW, COLOR_BLACK);
+        init_pair(16, COLOR_WHITE, COLOR_CYAN);
+        init_pair(17, COLOR_YELLOW, COLOR_CYAN);
         init_pair(18, COLOR_GREEN, COLOR_BLACK);
-        
-	STDATTR = COLOR_PAIR(14) | A_BOLD;
-	HIGHATTR = COLOR_PAIR(3) | A_BOLD;
-	BOXATTR = COLOR_PAIR(3);
-	ACTIVEATTR = COLOR_PAIR(10) | A_BOLD;
-	BARSTDATTR = COLOR_PAIR(15) | A_BOLD;
-	BARHIGHATTR = COLOR_PAIR(11) | A_BOLD;
-	BARPTRATTR = COLOR_PAIR(18) | A_BOLD;
-	DESCATTR = COLOR_PAIR(2);
-	DLGTEXTATTR = COLOR_PAIR(2);
-	DLGBOXATTR = COLOR_PAIR(6);
-	DLGHIGHATTR = COLOR_PAIR(12);
-	STATUSBARATTR = STDATTR;
-	IPSTATLABELATTR = COLOR_PAIR(2);
-	IPSTATATTR = COLOR_PAIR(12);
-	DESKTEXTATTR = COLOR_PAIR(7);
-	PTRATTR = COLOR_PAIR(10) | A_BOLD;
-	FIELDATTR = COLOR_PAIR(1);
-	ERRBOXATTR = COLOR_PAIR(5) | A_BOLD;
-	ERRTXTATTR = COLOR_PAIR(4) | A_BOLD;
-	OSPFATTR = COLOR_PAIR(2);
-	UDPATTR = COLOR_PAIR(9);
-	IGPATTR = COLOR_PAIR(12);
-	IGMPATTR = COLOR_PAIR(10) | A_BOLD;
-	IGRPATTR = COLOR_PAIR(16) | A_BOLD;
-	ARPATTR = COLOR_PAIR(5) | A_BOLD;
-	GREATTR = COLOR_PAIR(1);
-	UNKNATTR = COLOR_PAIR(4) | A_BOLD;
+        init_pair(19, COLOR_WHITE, COLOR_BLUE);
+
+        STDATTR = COLOR_PAIR(14) | A_BOLD;
+        HIGHATTR = COLOR_PAIR(3) | A_BOLD;
+        BOXATTR = COLOR_PAIR(3);
+        ACTIVEATTR = COLOR_PAIR(10) | A_BOLD;
+        BARSTDATTR = COLOR_PAIR(15) | A_BOLD;
+        BARHIGHATTR = COLOR_PAIR(11) | A_BOLD;
+        BARPTRATTR = COLOR_PAIR(18) | A_BOLD;
+        DESCATTR = COLOR_PAIR(2);
+        DLGTEXTATTR = COLOR_PAIR(2);
+        DLGBOXATTR = COLOR_PAIR(6);
+        DLGHIGHATTR = COLOR_PAIR(12);
+        STATUSBARATTR = STDATTR;
+        IPSTATLABELATTR = COLOR_PAIR(2);
+        IPSTATATTR = COLOR_PAIR(12);
+        DESKTEXTATTR = COLOR_PAIR(7);
+        PTRATTR = COLOR_PAIR(10) | A_BOLD;
+        FIELDATTR = COLOR_PAIR(1);
+        ERRBOXATTR = COLOR_PAIR(5) | A_BOLD;
+        ERRTXTATTR = COLOR_PAIR(4) | A_BOLD;
+        OSPFATTR = COLOR_PAIR(2);
+        UDPATTR = COLOR_PAIR(9);
+        IGPATTR = COLOR_PAIR(12);
+        IGMPATTR = COLOR_PAIR(10) | A_BOLD;
+        IGRPATTR = COLOR_PAIR(16) | A_BOLD;
+        ARPATTR = COLOR_PAIR(5) | A_BOLD;
+        GREATTR = COLOR_PAIR(1);
+        UNKNIPATTR = COLOR_PAIR(19) | A_BOLD;
+        UNKNATTR = COLOR_PAIR(4) | A_BOLD;
     } else {
-	STDATTR = A_REVERSE;
-	HIGHATTR = A_REVERSE;
-	BOXATTR = A_REVERSE;
-	ACTIVEATTR = A_BOLD;
-	BARSTDATTR = A_NORMAL;
-	BARHIGHATTR = A_BOLD;
-	BARPTRATTR = A_NORMAL;
-	DESCATTR = A_BOLD;
+        STDATTR = A_REVERSE;
+        HIGHATTR = A_REVERSE;
+        BOXATTR = A_REVERSE;
+        ACTIVEATTR = A_BOLD;
+        BARSTDATTR = A_NORMAL;
+        BARHIGHATTR = A_BOLD;
+        BARPTRATTR = A_NORMAL;
+        DESCATTR = A_BOLD;
         DLGBOXATTR = A_REVERSE;
         DLGTEXTATTR = A_REVERSE;
         DLGHIGHATTR = A_BOLD;
@@ -264,21 +269,21 @@ void standardcolors(int color)
         IPSTATLABELATTR = A_REVERSE;
         IPSTATATTR = A_STANDOUT;
         DESKTEXTATTR = A_NORMAL;
-	PTRATTR = A_REVERSE;
-	FIELDATTR = A_BOLD;
-	ERRBOXATTR = A_BOLD;
-	ERRTXTATTR = A_NORMAL;
-	OSPFATTR = A_REVERSE;
-	UDPATTR = A_BOLD;
-	IGPATTR = A_REVERSE;
-	IGMPATTR = A_REVERSE;
-	IGRPATTR = A_REVERSE;
-	ARPATTR = A_BOLD;
-	GREATTR = A_BOLD;
-	UNKNATTR = A_BOLD;
+        PTRATTR = A_REVERSE;
+        FIELDATTR = A_BOLD;
+        ERRBOXATTR = A_BOLD;
+        ERRTXTATTR = A_NORMAL;
+        OSPFATTR = A_REVERSE;
+        UDPATTR = A_BOLD;
+        IGPATTR = A_REVERSE;
+        IGMPATTR = A_REVERSE;
+        IGRPATTR = A_REVERSE;
+        ARPATTR = A_BOLD;
+        GREATTR = A_BOLD;
+        UNKNIPATTR = A_BOLD;
+        UNKNATTR = A_BOLD;
     }
-    
+
     tx_init_error_attrs(ERRBOXATTR, ERRTXTATTR, ERRBOXATTR);
     tx_init_info_attrs(BOXATTR, STDATTR, HIGHATTR);
 }
-
