@@ -3,7 +3,7 @@
 ifaces.c - routine that determines whether a given interface is supported
 		by IPTraf
 		
-Copyright (c) Gerard Paul Java 1998
+Copyright (c) Gerard Paul Java 1998, 2003
 
 This software is open source; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -32,21 +32,22 @@ details.
 #include "error.h"
 
 extern int accept_unsupported_interfaces;
-#define NUM_SUPPORTED_IFACES 20
+#define NUM_SUPPORTED_IFACES 26
 
 extern int daemonized;
 
 char ifaces[][6] =
     { "lo", "eth", "sl", "ppp", "ippp", "plip", "fddi", "isdn", "dvb",
-      "pvc", "hdlc", "ipsec", "sbni", "tr", "wvlan", "wlan", "sm2", "sm3",
-      "pent", "lec" };
+    "pvc", "hdlc", "ipsec", "sbni", "tr", "wvlan", "wlan", "sm2", "sm3",
+    "pent", "lec", "brg", "tun", "tap", "cipcb", "tunl", "vlan"
+};
 
 char *ltrim(char *buf)
 {
     char *tmp = buf;
 
     while ((*tmp == ' ') || (*tmp == '\t'))
-	tmp++;
+        tmp++;
 
     strcpy(buf, tmp);
     return buf;
@@ -69,8 +70,8 @@ FILE *open_procnetdev(void)
      */
 
     if (fd != NULL) {
-	fgets(buf, 160, fd);
-	fgets(buf, 160, fd);
+        fgets(buf, 160, fd);
+        fgets(buf, 160, fd);
     }
 
     return fd;
@@ -84,14 +85,14 @@ void get_next_iface(FILE * fd, char *ifname)
     char buf[161];
 
     if (!feof(fd)) {
-	strcpy(buf, "");
-	fgets(buf, 160, fd);
-	if (strcmp(buf, "") != 0)
-	    strcpy(ifname, ltrim(strtok(buf, ":")));
-	else
-	    strcpy(ifname, "");
+        strcpy(buf, "");
+        fgets(buf, 160, fd);
+        if (strcmp(buf, "") != 0)
+            strcpy(ifname, ltrim(strtok(buf, ":")));
+        else
+            strcpy(ifname, "");
     } else
-	strcpy(ifname, "");
+        strcpy(ifname, "");
 }
 
 /*
@@ -104,10 +105,10 @@ int iface_supported(char *iface)
 
     if (accept_unsupported_interfaces)
         return 1;
-        
+
     for (i = 0; i <= NUM_SUPPORTED_IFACES - 1; i++) {
-	if (strncmp(ifaces[i], iface, strlen(ifaces[i])) == 0)
-	    return 1;
+        if (strncmp(ifaces[i], iface, strlen(ifaces[i])) == 0)
+            return 1;
     }
 
     return 0;
@@ -127,7 +128,7 @@ int iface_up(char *iface)
     close(fd);
 
     if ((ir != 0) || (!(ifr.ifr_flags & IFF_UP)))
-	return 0;
+        return 0;
 
     return 1;
 }
@@ -145,19 +146,19 @@ void err_iface_down(void)
 void isdn_iface_check(int *fd, char *ifname)
 {
     if (*fd == -1) {
-	if (strncmp(ifname, "isdn", 4) == 0)
-	    *fd = open("/dev/isdnctrl", O_RDWR);
+        if (strncmp(ifname, "isdn", 4) == 0)
+            *fd = open("/dev/isdnctrl", O_RDWR);
     }
 }
 
 char *gen_iface_msg(char *ifptr)
 {
     static char if_msg[20];
-    
+
     if (ifptr == NULL)
         strcpy(if_msg, "all interfaces");
     else
         strncpy(if_msg, ifptr, 20);
-        
+
     return if_msg;
 }
