@@ -10,5 +10,6 @@ struct isdntab {
 };
 
 void add_isdn_entry(struct isdntab *list, char *ifname, int isdn_fd);
-struct isdntabent *isdn_table_lookup(struct isdntab *list, char *ifname, int isdn_fd);
-void  destroy_isdn_table(struct isdntab *list);
+struct isdntabent *isdn_table_lookup(struct isdntab *list, char *ifname,
+                                     int isdn_fd);
+void destroy_isdn_table(struct isdntab *list);
