@@ -22,14 +22,17 @@ GNU General Public License for more details.
 #define WITHOUTETCETHERS 0
 
 void etherr(void);
-void loaddesclist(struct desclist *list, unsigned int linktype, int withethers);
+void loaddesclist(struct desclist *list, unsigned int linktype,
+                  int withethers);
 void savedesclist(struct desclist *list, unsigned int linktype);
 void displayethdescs(struct desclist *list, WINDOW * win);
 void destroydesclist(struct desclist *list);
 void operate_descselect(struct desclist *list, struct desclistent **node,
-			WINDOW * win, int *aborted);
-void selectdesc(struct desclist *list, struct desclistent **node, int *aborted);
-void descdlg(struct descrec *rec, char *initaddr, char *initdesc, int *aborted);
+                        WINDOW * win, int *aborted);
+void selectdesc(struct desclist *list, struct desclistent **node,
+                int *aborted);
+void descdlg(struct descrec *rec, char *initaddr, char *initdesc,
+             int *aborted);
 void addethdesc(struct desclist *list);
 void editethdesc(struct desclist *list);
 void delethdesc(struct desclist *list);
