@@ -5,9 +5,11 @@
 #define LINK_LOOPBACK		5
 #define LINK_ISDN_RAWIP		6
 #define LINK_ISDN_CISCOHDLC	7
+#define LINK_CISCOHDLC  7
 #define LINK_FDDI		8
 #define LINK_FRAD		9
 #define LINK_DLCI		10
 #define LINK_TR			11
+#define LINK_IPIP       12
+#define LINK_VLAN       13
 #define LINK_INVALID		0
-
