@@ -42,59 +42,62 @@ details.
 void makeoptionmenu(struct MENU *menu)
 {
     tx_initmenu(menu, 19, 40, (LINES - 19) / 2 - 1, (COLS - 40) / 16,
-        BOXATTR, STDATTR, HIGHATTR, BARSTDATTR, BARHIGHATTR, DESCATTR);
+                BOXATTR, STDATTR, HIGHATTR, BARSTDATTR, BARHIGHATTR,
+                DESCATTR);
     tx_additem(menu, " ^R^everse DNS lookups",
-	    "Toggles resolution of IP addresses into host names");
+               "Toggles resolution of IP addresses into host names");
     tx_additem(menu, " TCP/UDP ^s^ervice names",
-	    "Displays TCP/UDP service names instead of numeric ports");
+               "Displays TCP/UDP service names instead of numeric ports");
     tx_additem(menu, " Force ^p^romiscuous mode",
-	    "Toggles capture of all packets by LAN interfaces");
+               "Toggles capture of all packets by LAN interfaces");
     tx_additem(menu, " ^C^olor",
-	    "Turns color on or off (restart IPTraf to effect change)");
+               "Turns color on or off (restart IPTraf to effect change)");
     tx_additem(menu, " ^L^ogging",
-	    "Toggles logging of traffic to a data file");
+               "Toggles logging of traffic to a data file");
     tx_additem(menu, " Acti^v^ity mode",
-	    "Toggles activity indicators between kbits/s and kbytes/s");
+               "Toggles activity indicators between kbits/s and kbytes/s");
     tx_additem(menu, " Source ^M^AC addrs in traffic monitor",
-            "Toggles display of source MAC addresses in the IP Traffic Monitor");
+               "Toggles display of source MAC addresses in the IP Traffic Monitor");
     tx_additem(menu, NULL, NULL);
     tx_additem(menu, " ^T^imers...", "Configures timeouts and intervals");
     tx_additem(menu, NULL, NULL);
     tx_additem(menu, " ^A^dditional ports...",
-	    "Allows you to add port numbers higher than 1023 for the service stats");
+               "Allows you to add port numbers higher than 1023 for the service stats");
     tx_additem(menu, " ^D^elete port/range...",
-	    "Deletes a port or range of ports earlier added");
+               "Deletes a port or range of ports earlier added");
     tx_additem(menu, NULL, NULL);
     tx_additem(menu, " ^E^thernet/PLIP host descriptions...",
-	    "Manages descriptions for Ethernet and PLIP addresses");
+               "Manages descriptions for Ethernet and PLIP addresses");
     tx_additem(menu, " ^F^DDI/Token Ring host descriptions...",
-	    "Manages descriptions for FDDI and FDDI addresses");
+               "Manages descriptions for FDDI and FDDI addresses");
     tx_additem(menu, NULL, NULL);
     tx_additem(menu, " E^x^it configuration", "Returns to main menu");
 }
 
 void maketimermenu(struct MENU *menu)
 {
-    tx_initmenu(menu, 7, 35, (LINES - 19) / 2 + 7, (COLS - 35) / 2,
-        BOXATTR, STDATTR, HIGHATTR, BARSTDATTR, BARHIGHATTR, DESCATTR);
+    tx_initmenu(menu, 8, 35, (LINES - 19) / 2 + 7, (COLS - 35) / 2,
+                BOXATTR, STDATTR, HIGHATTR, BARSTDATTR, BARHIGHATTR,
+                DESCATTR);
 
     tx_additem(menu, " TCP ^t^imeout...",
-	    "Sets the length of time before inactive TCP entries are considered idle");
+               "Sets the length of time before inactive TCP entries are considered idle");
     tx_additem(menu, " ^L^ogging interval...",
-	    "Sets the time between loggings for interface, host, and service stats");
+               "Sets the time between loggings for interface, host, and service stats");
     tx_additem(menu, " ^S^creen update interval...",
-	    "Sets the screen update interval in seconds (set to 0 for fastest updates)");
+               "Sets the screen update interval in seconds (set to 0 for fastest updates)");
     tx_additem(menu, " TCP closed/idle ^p^ersistence...",
-	    "Determines how long closed/idle/reset entries stay onscreen");
+               "Determines how long closed/idle/reset entries stay onscreen");
+    tx_additem(menu, NULL, NULL);
     tx_additem(menu, " E^x^it menu", "Returns to the configuration menu");
 }
 
 void printoptonoff(unsigned int option, WINDOW * win)
 {
     if (option)
-	wprintw(win, " On");
+        wprintw(win, " On");
     else
-	wprintw(win, "Off");
+        wprintw(win, "Off");
 }
 
 void indicatesetting(int row, struct OPTIONS *options, WINDOW * win)
@@ -104,32 +107,32 @@ void indicatesetting(int row, struct OPTIONS *options, WINDOW * win)
 
     switch (row) {
     case 1:
-	printoptonoff(options->revlook, win);
-	break;
+        printoptonoff(options->revlook, win);
+        break;
     case 2:
-	printoptonoff(options->servnames, win);
-	break;
+        printoptonoff(options->servnames, win);
+        break;
     case 3:
-	printoptonoff(options->promisc, win);
-	break;
+        printoptonoff(options->promisc, win);
+        break;
     case 4:
-	printoptonoff(options->color, win);
-	break;
+        printoptonoff(options->color, win);
+        break;
     case 5:
-	printoptonoff(options->logging, win);
-	break;
+        printoptonoff(options->logging, win);
+        break;
     case 6:
-	wmove(win, row, 25);
-	if (options->actmode == KBITS)
-	    wprintw(win, " kbits/s");
-	else
-	    wprintw(win, "kbytes/s");
+        wmove(win, row, 25);
+        if (options->actmode == KBITS)
+            wprintw(win, " kbits/s");
+        else
+            wprintw(win, "kbytes/s");
         break;
     case 7:
         printoptonoff(options->mac, win);
         break;
     }
-   
+
 }
 
 void saveoptions(struct OPTIONS *options)
@@ -141,13 +144,13 @@ void saveoptions(struct OPTIONS *options)
     fd = open(CONFIGFILE, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR);
 
     if (fd < 0) {
-	tx_errbox("Cannot create config file", ANYKEY_MSG, &response);
-	return;
+        tx_errbox("Cannot create config file", ANYKEY_MSG, &response);
+        return;
     }
     bw = write(fd, options, sizeof(struct OPTIONS));
 
     if (bw < 0)
-	tx_errbox("Unable to write config file", ANYKEY_MSG, &response);
+        tx_errbox("Unable to write config file", ANYKEY_MSG, &response);
 
     close(fd);
 }
@@ -176,7 +179,7 @@ void loadoptions(struct OPTIONS *options)
     fd = open(CONFIGFILE, O_RDONLY);
 
     if (fd < 0)
-	return;
+        return;
 
     br = read(fd, options, sizeof(struct OPTIONS));
 
@@ -197,13 +200,13 @@ void showoptions(struct OPTIONS *options, WINDOW * win)
     int i;
 
     for (i = 1; i <= 7; i++)
-	indicatesetting(i, options, win);
+        indicatesetting(i, options, win);
 
     updatetimes(options, win);
 }
 
 void settimeout(unsigned int *value, const char *units, int allow_zero,
-		int *aborted)
+                int *aborted)
 {
     WINDOW *dlgwin;
     PANEL *dlgpanel;
@@ -216,7 +219,7 @@ void settimeout(unsigned int *value, const char *units, int allow_zero,
 
     wattrset(dlgwin, DLGBOXATTR);
     tx_colorwin(dlgwin);
-    box(dlgwin, ACS_VLINE, ACS_HLINE);
+    tx_box(dlgwin, ACS_VLINE, ACS_HLINE);
 
     wattrset(dlgwin, DLGTEXTATTR);
     wmove(dlgwin, 2, 2);
@@ -225,21 +228,21 @@ void settimeout(unsigned int *value, const char *units, int allow_zero,
     stdkeyhelp(dlgwin);
 
     tx_initfields(&field, 1, 10, (LINES - 7) / 2 + 3, (COLS - 40) / 4 + 2,
-        DLGTEXTATTR, FIELDATTR);
+                  DLGTEXTATTR, FIELDATTR);
     tx_addfield(&field, 3, 0, 0, "");
 
     do {
-	tx_fillfields(&field, aborted);
+        tx_fillfields(&field, aborted);
 
-	if (!(*aborted)) {
-	    tmval = atoi(field.list->buf);
-	    if ((!allow_zero) && (tmval == 0))
-		tx_errbox("Invalid timeout value", ANYKEY_MSG, &resp);
-	}
+        if (!(*aborted)) {
+            tmval = atoi(field.list->buf);
+            if ((!allow_zero) && (tmval == 0))
+                tx_errbox("Invalid timeout value", ANYKEY_MSG, &resp);
+        }
     } while (((!allow_zero) && (tmval == 0)) && (!(*aborted)));
 
     if (!(*aborted))
-	*value = tmval;
+        *value = tmval;
 
     del_panel(dlgpanel);
     delwin(dlgwin);
@@ -252,29 +255,29 @@ void settimeout(unsigned int *value, const char *units, int allow_zero,
 void setoptions(struct OPTIONS *options, struct porttab **ports)
 {
     int row = 1;
-    int trow = 1;        /* row for timer submenu */
+    int trow = 1;               /* row for timer submenu */
     int aborted;
     int resp;
 
     struct MENU menu;
     struct MENU timermenu;
-    
+
     WINDOW *statwin;
     PANEL *statpanel;
 
     if (!is_first_instance) {
-	tx_errbox("Only the first instance of IPTraf can configure",
-	       ANYKEY_MSG, &resp);
-	return;
+        tx_errbox("Only the first instance of IPTraf can configure",
+                  ANYKEY_MSG, &resp);
+        return;
     }
     makeoptionmenu(&menu);
-    
+
     statwin = newwin(14, 35, (LINES - 19) / 2 - 1, (COLS - 40) / 16 + 40);
     statpanel = new_panel(statwin);
 
     wattrset(statwin, BOXATTR);
     tx_colorwin(statwin);
-    box(statwin, ACS_VLINE, ACS_HLINE);
+    tx_box(statwin, ACS_VLINE, ACS_HLINE);
     wmove(statwin, 8, 1);
     whline(statwin, ACS_HLINE, 33);
     mvwprintw(statwin, 0, 1, " Current Settings ");
@@ -293,85 +296,87 @@ void setoptions(struct OPTIONS *options, struct porttab **ports)
     showoptions(options, statwin);
 
     do {
-	tx_showmenu(&menu);
-	tx_operatemenu(&menu, &row, &aborted);
+        tx_showmenu(&menu);
+        tx_operatemenu(&menu, &row, &aborted);
 
-	switch (row) {
-	case 1:
-	    options->revlook = ~(options->revlook);
-	    break;
-	case 2:
-	    options->servnames = ~(options->servnames);
-	    break;
-	case 3:
-	    options->promisc = ~(options->promisc);
-	    break;
-	case 4:
-	    options->color = ~(options->color);
-	    break;
-	case 5:
-	    options->logging = ~(options->logging);
-	    break;
-	case 6:
-	    options->actmode = ~(options->actmode);
-	    break;
-	case 7:
-	    options->mac = ~(options->mac);
-	    break;
-	case 9:
+        switch (row) {
+        case 1:
+            options->revlook = ~(options->revlook);
+            break;
+        case 2:
+            options->servnames = ~(options->servnames);
+            break;
+        case 3:
+            options->promisc = ~(options->promisc);
+            break;
+        case 4:
+            options->color = ~(options->color);
+            break;
+        case 5:
+            options->logging = ~(options->logging);
+            break;
+        case 6:
+            options->actmode = ~(options->actmode);
+            break;
+        case 7:
+            options->mac = ~(options->mac);
+            break;
+        case 9:
             maketimermenu(&timermenu);
-	    do {
-	        tx_showmenu(&timermenu);
-	        tx_operatemenu(&timermenu, &trow, &aborted);
-	        
-	        switch(trow) {
-	        case 1:
-	            settimeout(&(options->timeout), "minutes", DONT_ALLOW_ZERO,
-		           &aborted);
-	            if (!aborted)
-		        updatetimes(options, statwin);
-	            break;
-		case 2:
-	            settimeout((unsigned int *) &(options->logspan), "minutes",
-		               DONT_ALLOW_ZERO, &aborted);
-	            if (!aborted) {
-		        options->logspan = options->logspan * 60;
-		        updatetimes(options, statwin);
-	            }
-	            break;
-	        case 3:
-	            settimeout(&options->updrate, "seconds", ALLOW_ZERO, &aborted);
-	            if (!aborted)
-		        updatetimes(options, statwin);
-	            break;
-	        case 4:
-	            settimeout(&options->closedint, "minutes", ALLOW_ZERO,
-		               &aborted);
-	            if (!aborted)
-		        updatetimes(options, statwin);
-	            break;
-	        }
-	    } while (trow != 5);
-	    
-	    tx_destroymenu(&timermenu);
-	    update_panels();
-	    doupdate();
-	    break;
-	case 11:
-	    addmoreports(ports);
-	    break;
-	case 12:
-	    removeaport(ports);
-	    break;
-	case 14:
-	    ethdescmgr(LINK_ETHERNET);
-	    break;
-	case 15:
-	    ethdescmgr(LINK_FDDI);
-	    break;
-	}
+            trow = 1;
+            do {
+                tx_showmenu(&timermenu);
+                tx_operatemenu(&timermenu, &trow, &aborted);
 
-	indicatesetting(row, options, statwin);
+                switch (trow) {
+                case 1:
+                    settimeout(&(options->timeout), "minutes",
+                               DONT_ALLOW_ZERO, &aborted);
+                    if (!aborted)
+                        updatetimes(options, statwin);
+                    break;
+                case 2:
+                    settimeout((unsigned int *) &(options->logspan),
+                               "minutes", DONT_ALLOW_ZERO, &aborted);
+                    if (!aborted) {
+                        options->logspan = options->logspan * 60;
+                        updatetimes(options, statwin);
+                    }
+                    break;
+                case 3:
+                    settimeout(&options->updrate, "seconds", ALLOW_ZERO,
+                               &aborted);
+                    if (!aborted)
+                        updatetimes(options, statwin);
+                    break;
+                case 4:
+                    settimeout(&options->closedint, "minutes", ALLOW_ZERO,
+                               &aborted);
+                    if (!aborted)
+                        updatetimes(options, statwin);
+                    break;
+                }
+            } while (trow != 6);
+
+            tx_destroymenu(&timermenu);
+            update_panels();
+            doupdate();
+            break;
+        case 11:
+            addmoreports(ports);
+            break;
+        case 12:
+            removeaport(ports);
+            break;
+        case 14:
+            ethdescmgr(LINK_ETHERNET);
+            break;
+        case 15:
+            ethdescmgr(LINK_FDDI);
+            break;
+        }
+
+        indicatesetting(row, options, statwin);
     } while (row != 17);
 
     tx_destroymenu(&menu);
