@@ -4,7 +4,8 @@
 #define CHILDSOCKNAME "/dev/rvndcldcomsk"
 #define PARENTSOCKNAME "/dev/rvndpntcomsk"
 #define IPTSOCKNAME "/dev/rvndiptcomsk"
-#define IPTCLSOCKNAME "/dev/rvndipccomsk"
+
+#define SOCKET_PREFIX	"isock"
 
 #define NOTRESOLVED 0
 #define RESOLVING 1
@@ -15,6 +16,8 @@
 #define RVN_REPLY 2
 #define RVN_QUIT 3
 
+#define MAX_RVNAMED_CHILDREN	200
+
 struct rvn {
     int type;
     int ready;
