@@ -6,5 +6,4 @@ servname.h - function prototype for service lookup
 
 void servlook(int servnames,
               unsigned int port,
-              unsigned int protocol,
-              char *target, int maxlen);
+              unsigned int protocol, char *target, int maxlen);
