@@ -14,15 +14,16 @@ unsigned int get_tr_ip_offset(unsigned char *pkt)
 {
     struct trh_hdr *trh;
     unsigned int riflen = 0;
-    
+
     trh = (struct trh_hdr *) pkt;
-    
+
     /*
      * Check if this packet has TR routing information and get
      * its length.
      */
     if (trh->saddr[0] & TR_RII)
         riflen = (ntohs(trh->rcf) & TR_RCF_LEN_MASK) >> 8;
-        
-    return sizeof(struct trh_hdr) - TR_MAXRIFLEN + riflen + sizeof(struct trllc);
+
+    return sizeof(struct trh_hdr) - TR_MAXRIFLEN + riflen +
+        sizeof(struct trllc);
 }
